==> geant4.10.05.p01.tar.gz: geant4.10.05.p01/source/geometry/management/src/G4VPVDivisionFactory.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
//
// class G4VPVDivisionFactory Implementation file
//
// Author: Ivana Hrivnacova, 4.5.2004  (Ivana.Hrivnacova@cern.ch)
// ------------------------------------------------------------------------

#include "G4VPVDivisionFactory.hh"

G4ThreadLocal G4VPVDivisionFactory* G4VPVDivisionFactory::fgInstance = 0;

//_____________________________________________________________________________

G4VPVDivisionFactory* G4VPVDivisionFactory::Instance() 
{
  // Static singleton access method.
  // ---
  return fgInstance;
}  


//_____________________________________________________________________________

G4VPVDivisionFactory::G4VPVDivisionFactory()
{
  // Protected singleton constructor.
  // ---
  // fgInstance = this;
}

//_____________________________________________________________________________

G4VPVDivisionFactory::~G4VPVDivisionFactory()
{
}

==> geant4.10.06.tar.gz: geant4.10.06/source/geometry/management/src/G4VPVDivisionFactory.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// class G4VPVDivisionFactory Implementation file
//
// Author: Ivana Hrivnacova, 4.5.2004
// ------------------------------------------------------------------------

#include "G4VPVDivisionFactory.hh"

G4ThreadLocal G4VPVDivisionFactory* G4VPVDivisionFactory::fgInstance = nullptr;

//_____________________________________________________________________________

G4VPVDivisionFactory* G4VPVDivisionFactory::Instance() 
{
  // Static singleton access method.
  // ---
  return fgInstance;
}  


//_____________________________________________________________________________

G4VPVDivisionFactory::G4VPVDivisionFactory()
{
  // Protected singleton constructor.
  // ---
  // fgInstance = this;
}

//_____________________________________________________________________________

G4VPVDivisionFactory::~G4VPVDivisionFactory()
{
}
